==> haskell-protolude-0.2.3-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: protolude
version: 0.2.3
id: protolude-0.2.3-GEZB1Cb4BMm8mUNXAEJuLw
key: protolude-0.2.3-GEZB1Cb4BMm8mUNXAEJuLw
license: MIT
copyright: 2016-2018 Stephen Diehl
maintainer: stephen.m.diehl@gmail.com
author: Stephen Diehl
homepage: https://github.com/sdiehl/protolude
synopsis: A small prelude.
description:
    A sensible set of defaults for writing custom Preludes.
category: Prelude
abi: 40034f8cd0f01056d071f3831a7ae4a5
exposed: True
exposed-modules:
    Debug Protolude Protolude.Applicative Protolude.Base
    Protolude.Bifunctor Protolude.Bool Protolude.CallStack
    Protolude.Conv Protolude.Either Protolude.Error
    Protolude.Exceptions Protolude.Functor Protolude.List
    Protolude.Monad Protolude.Panic Protolude.Safe Protolude.Semiring
    Protolude.Show Unsafe
import-dirs: /usr/lib/ghc-8.6.5/site-local/protolude-0.2.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/protolude-0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/protolude-0.2.3
hs-libraries: HSprotolude-0.2.3-GEZB1Cb4BMm8mUNXAEJuLw
depends:
    array-0.5.3.0 async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo mtl-2.2.2
    stm-2.5.0.0 text-1.2.3.1 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html: /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-protolude-0.2.3-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: protolude
version: 0.2.3
id: protolude-0.2.3-GImAE5SPJdhAOkFEJUpXPz
key: protolude-0.2.3-GImAE5SPJdhAOkFEJUpXPz
license: MIT
copyright: 2016-2018 Stephen Diehl
maintainer: stephen.m.diehl@gmail.com
author: Stephen Diehl
homepage: https://github.com/sdiehl/protolude
synopsis: A small prelude.
description:
    A sensible set of defaults for writing custom Preludes.
category: Prelude
abi: 8ffecf3b39dd949aaa57227b6e84e8b5
exposed: True
exposed-modules:
    Debug Protolude Protolude.Applicative Protolude.Base
    Protolude.Bifunctor Protolude.Bool Protolude.CallStack
    Protolude.Conv Protolude.Either Protolude.Error
    Protolude.Exceptions Protolude.Functor Protolude.List
    Protolude.Monad Protolude.Panic Protolude.Safe Protolude.Semiring
    Protolude.Show Unsafe
import-dirs: /usr/lib/ghc-8.6.5/site-local/protolude-0.2.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/protolude-0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/protolude-0.2.3
hs-libraries: HSprotolude-0.2.3-GImAE5SPJdhAOkFEJUpXPz
depends:
    array-0.5.3.0 async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo mtl-2.2.2
    stm-2.5.0.0 text-1.2.3.1 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html: /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
